@@ -13,7 +13,7 @@ has options =>
     } );
 
 has skip_session => 
-    ( is => 'rw' , isa => 'bool' ,    default => sub { 0 } );
+    ( is => 'rw' , isa => 'Bool' ,    default => sub { 0 } );
 
 has podata =>
     ( is => 'rw' , isa => 'HashRef' , default => sub { +{  } } );
